import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;

/**
 * The class Gui implements the graphical interface of a simple stopwatch.
 * @see Timer
 * @author  Beatrice Amrhein
 * @version 24. April 2001
 */

public class Gui extends JFrame implements Observer {

  /**
  * The timer of the stopwatch.
  */
  private Timer timer;
  /**
  * A panel with two labels to show measured time.
  */
  private JLabel time;
  /**
  * The start button starts the timer.
  */
  private JButton start;
  /**
  * The stop button stops the timer.
  */
  private JButton stop;
  /**
  * The reset button resets the timer to zero.
  */
  private JButton reset;
  /**
  * The status label prints the status of the stopwatch.
  */
  private JLabel status;

  public Gui( Timer t ) {
    super( "Stopwatch" );
    this.timer = t;


    getContentPane().setLayout( new BorderLayout());
    status = new JLabel("Stopped");
    getContentPane().add(status, BorderLayout.SOUTH);

    JPanel p = new JPanel( new BorderLayout( 5, 5 ) );
    getContentPane().add(p);


    // create panel for timer output
    JPanel p1  = new JPanel(new GridLayout(1,2,3,3));
    p1.setFont( new Font( "Dialog", Font.BOLD, 20 ));
    p1.setBorder(new TitledBorder(new EtchedBorder(), "Display" ));
    p1.setBackground( new Color(240,240,240) );
    p.add( p1 );

    JLabel label = new JLabel("Sekunden:", SwingConstants.CENTER );
    label.setFont( null );
    p1.add( label );
    time = new JLabel( "0.0", SwingConstants.CENTER );
    time.setFont( null );
    p1.add( time );


    // create panel for buttons
    JPanel p2 = new JPanel( new GridLayout(1,3,4,4));
    p2.setFont( new Font( "Dialog", Font.BOLD, 20 ));
    p.add( p2, BorderLayout.SOUTH );

    start = new ControlButton("Start", p2);
    start.addActionListener(new CommandStart());
    stop = new ControlButton("Stop", p2);
    stop.addActionListener(new CommandStop());
    reset = new ControlButton("Reset", p2);
    reset.addActionListener(new CommandReset());

    // listen to Window event windowClosing
    addWindowListener( new WindowAdapter() {
      public void windowClosing( WindowEvent e ) {
          System.exit(0); }
    });

    setSize( 320,200 );
    setLocation(100,100);
  }






   /**
    * The inner class CommandStart is the ActionListener of the start button.
    */
   public class CommandStart implements ActionListener {
   
     public void actionPerformed(ActionEvent e) {
       //...
     }
   }

   /**
    * The inner class CommandStop is the ActionListener of the stop button.
    */
   public class CommandStop implements ActionListener {
   
     public void actionPerformed(ActionEvent e) {
       //...
     }
   }



   /**
    * The inner class CommandReset is the ActionListener of the reset button.
    */
   public class CommandReset implements ActionListener {
   
     public void actionPerformed(ActionEvent e) {
       //...
     }
   }




}


class ControlButton extends JButton {
  ControlButton(String s, JPanel p) {
    setText(s);
    setFont( null );
    setFocusPainted(false);
    p.add( this );
  }
}

